@@ -24,13 +24,14 @@ class Component(ABC):
     """
 
     kinds = {}
+    styles = {}
     can_stretch = False
     default_kind = ''
-    xoffset = 0
-    yoffset = 0
+    default_style = ''
     schematic_kind = False
+    label_offset = 0.6
 
-    def __init__(self, value: Union[str, int, float], kind=''):
+    def __init__(self, value: Union[str, int, float], kind='', style=''):
 
         self.name = None
         self.value: str = value
@@ -43,14 +44,27 @@ class Component(ABC):
         self.label = ''
         self.voltage_label = ''
         self.current_label = ''
+        self.flow_label = ''
+        self.color = ''
         self.angle = 0
 
         if kind == '':
             kind = self.default_kind
-
         self.kind = kind
         self.inv_kinds = {v: k for k, v in self.kinds.items()}
 
+        if style == '':
+            style = self.default_style
+        self.style = style
+        self.inv_styles = {v: k for k, v in self.styles.items()}
+
+        self.fields = {'label': 'Label',
+                       'voltage_label': 'Voltage label',
+                       'current_label': 'Current label',
+                       'flow_label': 'Flow label',
+                       'color': 'Color',
+                       'attrs': 'Attributes'}
+
     @property
     @classmethod
     @abstractmethod
@@ -80,10 +94,12 @@ class Component(ABC):
     @property
     def sketch_key(self):
 
+        s = self.TYPE
         if self.kind != '':
-            return self.TYPE + '-' + self.kind
-        else:
-            return self.TYPE
+            s += '-' + self.kind
+        if self.style != '':
+            s += '-' + self.style
+        return s
 
     def draw(self, editor, layer, **kwargs):
         """
@@ -112,9 +128,11 @@ class Component(ABC):
         p1p = p1 + dp
 
         lw = kwargs.pop('lw', editor.preferences.lw)
+        if self.color != '':
+            kwargs['color'] = self.color
 
-        self.sketch.draw(layer.ax, offset=p1p, angle=angle, lw=lw,
-                         snap=True, **kwargs)
+        layer.sketch(self.sketch, offset=p1p, angle=angle, lw=lw,
+                     snap=True, **kwargs)
 
         if self.can_stretch:
             p2 = array((x2, y2))
@@ -123,6 +141,8 @@ class Component(ABC):
             layer.stroke_line(*p1, *p1p, lw=lw, **kwargs)
             layer.stroke_line(*p2p, *p2, lw=lw, **kwargs)
 
+        # TODO, add label, voltage_label, current_label, flow_label
+
     def length(self) -> float:
         """
         Computes the length of the component.
@@ -176,12 +196,11 @@ class Component(ABC):
     @property
     def label_position(self) -> array:
         """
-        Returns position where to place label.   This should be
-        customised for each component.
+        Returns position where to place label.
         """
 
         pos = self.midpoint
-        w = 0.75
+        w = self.label_offset
         if self.vertical:
             pos[0] += w
         else:
@@ -264,6 +283,16 @@ class Component(ABC):
             # TODO: fix for other orientations
             attr = 'right'
 
+        if self.color != '':
+            attr += ', color=' + self.color
+        # TODO, add cunning way of specifing modifiers, e.g., v^, i<
+        if self.voltage_label != '':
+            attr += ', v=' + self.voltage_label
+        if self.current_label != '':
+            attr += ', i=' + self.current_label
+        if self.flow_label != '':
+            attr += ', f=' + self.flow_label
+
         # Add user defined attributes such as color=blue, thick, etc.
         if self.attrs != '':
             attr += ', ' + self.attrs
@@ -271,6 +300,9 @@ class Component(ABC):
         if self.schematic_kind and self.kind not in (None, ''):
             attr += ', kind=' + self.kind
 
+        if self.style not in (None, ''):
+            attr += ', style=' + self.style
+
         return ' '.join(parts) + '; ' + attr
 
 
