@@ -15,7 +15,7 @@ class CurrentSource(BipoleComponent):
     TYPE = 'I'
     NAME = 'Current Source'
     kinds = {'dc': 'DC', 'ac': 'AC', 'step': 'Step',
-             '': 'Arbitrary', 'noise': 'Noise'}
+             '': 'Arbitrary', 'noise': 'Noise', 's': ''}
     default_kind = ''
 
     @property
