@@ -3,10 +3,10 @@ from tkinter.ttk import Notebook
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.backends.backend_tkagg import NavigationToolbar2Tk
-from numpy import arange
 from os.path import basename
 from ..uimodelmph import UIModelMPH
 from .layer import Layer
+from .drawing import Drawing
 
 
 class LcapyTk(Tk):
@@ -52,8 +52,12 @@ class LcapyTk(Tk):
                                    underline=0, accelerator='Ctrl+o')
         self.file_menu.add_command(label='Save', command=self.on_save,
                                    underline=0, accelerator='Ctrl+s')
+        self.file_menu.add_command(label='Save as', command=self.on_save_as,
+                                   underline=1, accelerator='Alt+s')
         self.file_menu.add_command(label='Export', command=self.on_export,
                                    underline=0, accelerator='Ctrl+e')
+        self.file_menu.add_command(label='Screenshot', command=self.on_screenshot,
+                                   underline=1)
         self.file_menu.add_command(label='Quit', command=self.on_quit,
                                    underline=0, accelerator='Ctrl+q')
 
@@ -96,6 +100,10 @@ class LcapyTk(Tk):
                                    command=self.on_nodal_equations)
         self.view_menu.add_command(label='Mesh equations',
                                    command=self.on_mesh_equations)
+        self.view_menu.add_command(label='Best fit',
+                                   command=self.on_best_fit)
+        self.view_menu.add_command(label='Default fit',
+                                   command=self.on_default_fit)
 
         self.menu.add_cascade(label='View', underline=0, menu=self.view_menu)
 
@@ -186,8 +194,7 @@ class LcapyTk(Tk):
 
     def clear(self, grid='on'):
 
-        self.layer.clear()
-        self.canvas.drawing.draw_grid(grid)
+        self.canvas.drawing.clear(grid)
 
     def display(self):
 
@@ -228,7 +235,7 @@ class LcapyTk(Tk):
         self.notebook.pack(fill=BOTH, expand=1)
 
         # Add the figure to the graph tab
-        fig = Figure(figsize=self.FIGSIZE)
+        fig = Figure(figsize=self.FIGSIZE, frameon=False)
         fig.subplots_adjust(left=0, bottom=0, right=1,
                             top=1, wspace=0, hspace=0)
 
@@ -240,7 +247,7 @@ class LcapyTk(Tk):
         toolbar.update()
         toolbar.pack(side=BOTTOM, fill=X)
 
-        drawing = Drawing(self, fig)
+        drawing = Drawing(self, fig, self.debug)
         canvas.drawing = drawing
         canvas.tab = tab
         canvas.layer = Layer(canvas.drawing.ax)
@@ -290,6 +297,10 @@ class LcapyTk(Tk):
 
         self.model.on_add_cpt(cptname)
 
+    def on_best_fit(self, *args):
+
+        self.model.on_best_fit()
+
     def on_click_event(self, event):
 
         if self.debug:
@@ -319,6 +330,11 @@ class LcapyTk(Tk):
 
         self.model.on_cut()
 
+    def on_default_fit(self, *args):
+
+        self.canvas.drawing.set_default_view()
+        self.refresh()
+
     def on_enter(self, event):
 
         # TODO, determine tab from mouse x, y
@@ -417,16 +433,20 @@ class LcapyTk(Tk):
 
     def on_quit(self, *args):
 
-        if self.debug:
-            print('Quit')
         self.model.on_quit()
 
     def on_save(self, *args):
 
-        if self.debug:
-            print('Save')
         self.model.on_save()
 
+    def on_save_as(self, *args):
+
+        self.model.on_save_as()
+
+    def on_screenshot(self, *args):
+
+        self.model.on_screenshot()
+
     def on_tab_selected(self, event):
 
         notebook = event.widget
@@ -451,7 +471,7 @@ class LcapyTk(Tk):
 
     def refresh(self):
 
-        self.canvas.drawing.fig.canvas.draw()
+        self.canvas.drawing.refresh()
 
     def quit(self):
 
@@ -462,10 +482,18 @@ class LcapyTk(Tk):
         name = basename(filename)
         self.set_canvas_title(name)
 
+    def screenshot(self, filename):
+
+        self.canvas.drawing.savefig(filename)
+
     def set_canvas_title(self, name):
 
         self.notebook.tab('current', text=name)
 
+    def set_view(self, xmin, ymin, xmax, ymax):
+
+        self.canvas.drawing.set_view(xmin, ymin, xmax, ymax)
+
     def show_equations_dialog(self, expr, title=''):
 
         from .equations_dialog import EquationsDialog
@@ -564,7 +592,7 @@ class LcapyTk(Tk):
 
         return asksaveasfilename(**options)
 
-    def export_file_dialog(self, filename):
+    def export_file_dialog(self, filename, default_ext=None):
 
         from tkinter.filedialog import asksaveasfilename
         from os.path import dirname, splitext, basename
@@ -572,6 +600,9 @@ class LcapyTk(Tk):
         dirname = dirname(filename)
         basename, ext = splitext(basename(filename))
 
+        if default_ext is not None:
+            ext = default_ext
+
         options = {}
         options['defaultextension'] = ext
         options['filetypes'] = (("Embeddable LaTeX", "*.schtex"),
@@ -584,34 +615,3 @@ class LcapyTk(Tk):
         options['title'] = "Export file"
 
         return asksaveasfilename(**options)
-
-
-class Drawing():
-
-    def __init__(self, ui, fig):
-
-        self.ui = ui
-        self.fig = fig
-        self.ax = self.fig.add_subplot(111)
-
-        self.draw_grid('on')
-
-    def draw_grid(self, grid):
-
-        xticks = arange(self.ui.XSIZE)
-        yticks = arange(self.ui.YSIZE)
-
-        self.ax.axis('equal')
-        self.ax.set_xlim(0, self.ui.XSIZE)
-        self.ax.set_ylim(0, self.ui.YSIZE)
-        self.ax.set_xticks(xticks)
-        self.ax.set_yticks(yticks)
-        self.ax.set_xticklabels([])
-        self.ax.set_yticklabels([])
-        if grid == 'on':
-            self.ax.grid(color='lightblue')
-
-        self.ax.tick_params(which='both', left=False, bottom=False,
-                            top=False, labelbottom=False)
-
-        self.ax.set_axisbelow(True)
