@@ -34,6 +34,13 @@ class PreferencesDialog:
                               command=self.on_update),
                    LabelEntry('lw', 'Line width',
                               self.model.preferences.lw,
+                              command=self.on_update),
+                   LabelEntry('node_size', 'Node size',
+                              self.model.preferences.node_size,
+                              command=self.on_update),
+                   LabelEntry('show_units', 'Show units',
+                              self.model.preferences.show_units,
+                              ('true', 'false'),
                               command=self.on_update)
                    ]
 
@@ -51,6 +58,11 @@ class PreferencesDialog:
         self.model.preferences.style = self.labelentries.get('style')
         self.model.preferences.grid = self.labelentries.get('grid')
         self.model.preferences.lw = self.labelentries.get('lw')
+        self.model.preferences.node_size = self.labelentries.get('node_size')
+        self.model.preferences.show_units = self.labelentries.get('show_units')
+
+        # Do not set show_units; this needs fixing in Lcapy since
+        # str(expr) includes the units and this causes problems...
 
         if self.update:
             # Could check for changes
