@@ -97,15 +97,35 @@ class UIModelBase:
 
         return self._cct
 
-    def annotation_make(self, elt, kind=''):
+    def annotation_make(self, elt, kind='', style=''):
 
         opts = elt.opts
 
         for k, v in self.connection_map.items():
             if k in opts:
-                return self.con_make(k, kind)
+                return self.con_make(k, kind, style)
         return None
 
+    def bounding_box(self):
+
+        if len(self.nodes) == 0:
+            return None
+
+        xmin = 1000
+        xmax = 0
+        ymin = 1000
+        ymax = 0
+        for node in self.nodes:
+            if node.x < xmin:
+                xmin = node.x
+            if node.x > xmax:
+                xmax = node.x
+            if node.y < ymin:
+                ymin = node.y
+            if node.y > ymax:
+                ymax = node.y
+        return xmin, ymin, xmax, ymax
+
     def con_create(self, con_key, x1, y1, x2, y2):
         """Make and place a connection."""
 
@@ -115,7 +135,7 @@ class UIModelBase:
             return
         self.cpt_place(cpt, x1, y1, x2, y2)
 
-    def con_make(self, con_key, kind=''):
+    def con_make(self, con_key, kind='', style=''):
 
         try:
             cpt_class_name = self.connection_map[con_key][1]
@@ -127,7 +147,7 @@ class UIModelBase:
         if cpt_class_name == '':
             return None
 
-        cpt = cpt_make(cpt_class_name, kind)
+        cpt = cpt_make(cpt_class_name, kind, style)
         self.invalidate()
         return cpt
 
@@ -228,7 +248,7 @@ class UIModelBase:
                 ann.draw(fontsize=18)
                 cpt.annotations.append(ann)
 
-    def cpt_make(self, cpt_key, cpt_kind=''):
+    def cpt_make(self, cpt_key, kind='', style=''):
 
         try:
             cpt_class_name = self.component_map[cpt_key][1]
@@ -238,7 +258,7 @@ class UIModelBase:
         if cpt_class_name == '':
             return None
 
-        cpt = cpt_make(cpt_class_name, cpt_kind)
+        cpt = cpt_make(cpt_class_name, kind, style)
         self.invalidate()
         return cpt
 
@@ -295,7 +315,7 @@ class UIModelBase:
 
     def export(self, filename):
 
-        cct = self._cct
+        cct = self.cct
         cct.draw(filename)
 
     def invalidate(self):
@@ -308,14 +328,26 @@ class UIModelBase:
 
         self.filename = filename
 
+        with open(filename) as f:
+            line = f.readline()
+            if line.startswith(r'\begin{tikz'):
+                self.ui.show_error_dialog('Cannot load Circuitikz macro file')
+                return
+
         self.components.clear()
 
-        cct = Circuit(filename)
+        try:
+            cct = Circuit(filename)
+        except Exception as e:
+            self.exception(e)
+            return
 
         self.load_from_circuit(cct)
 
     def load_from_circuit(self, cct):
 
+        # TODO: use Lcapy parser
+
         sch = cct.sch
 
         try:
@@ -345,6 +377,11 @@ class UIModelBase:
             else:
                 kind = ''
 
+            if 'style' in elt.opts:
+                style = elt.opts['style']
+            else:
+                style = ''
+
             # Handle electrical kind
             if elt.keyword and elt.keyword[0] is not None:
                 kind = elt.keyword[1]
@@ -355,9 +392,9 @@ class UIModelBase:
             elif isinstance(elt, Eopamp):
                 cpt = self.cpt_make('opamp')
             elif elt.type == 'A':
-                cpt = self.annotation_make(elt, kind)
+                cpt = self.annotation_make(elt, kind, style)
             else:
-                cpt = self.cpt_make(elt.type.lower(), kind)
+                cpt = self.cpt_make(elt.type.lower(), kind, style)
             if cpt is None:
                 self.exception('Unhandled component ' + str(elt.name))
                 return
@@ -406,7 +443,7 @@ class UIModelBase:
 
             attrs = []
             for opt, val in elt.opts.items():
-                if opt in ('left', 'right', 'up', 'down', 'rotate', 'kind'):
+                if opt in ('left', 'right', 'up', 'down', 'rotate', 'kind', 'style'):
                     continue
 
                 def fmt(key, val):
@@ -547,7 +584,7 @@ class UIModelBase:
 
     def view(self):
 
-        cct = self._cct
+        cct = self.cct
         cct.draw()
 
     def voltage_annotate(self, cpt):
@@ -604,3 +641,4 @@ class UIModelBase:
             self.select(cpt)
         else:
             self.cpt_delete(cpt)
+        self.invalidate()
