@@ -69,6 +69,7 @@ class UIModelMPH(UIModelBase):
             'ctrl+n': self.on_new,
             'ctrl+o': self.on_load,
             'ctrl+s': self.on_save,
+            'alt+s': self.on_save_as,
             'ctrl+u': self.on_view,
             'ctrl+v': self.on_paste,
             'ctrl+w': self.on_quit,
@@ -206,6 +207,16 @@ class UIModelMPH(UIModelBase):
         self.con_create(con_key, x1, y1, x2, y2)
         self.ui.refresh()
 
+    def on_best_fit(self):
+
+        bbox = self.bounding_box()
+        if bbox is None:
+            return
+        xmin, ymin, xmax, ymax = bbox
+
+        self.ui.set_view(xmin - 2, ymin - 2, xmax + 2, ymax + 2)
+        self.ui.refresh()
+
     def on_close(self):
 
         self.ui.quit()
@@ -223,6 +234,7 @@ class UIModelMPH(UIModelBase):
             # If kind has changed need to remake the sketch
             cpt_remake(cpt)
         self.redraw()
+        self.cursors.draw()
         self.ui.refresh()
 
     def on_debug(self):
@@ -348,7 +360,7 @@ class UIModelMPH(UIModelBase):
     def on_load(self):
 
         filename = self.ui.open_file_dialog()
-        if filename == '':
+        if filename == '' or filename == ():
             return
 
         model = self.ui.new()
@@ -365,6 +377,7 @@ class UIModelMPH(UIModelBase):
             la = self.cct.loop_analysis()
         except Exception as e:
             self.exception(e)
+            return
 
         eqns = la.mesh_equations()
         self.ui.show_equations_dialog(eqns, 'Mesh equations')
@@ -392,6 +405,8 @@ class UIModelMPH(UIModelBase):
             na = self.cct.nodal_analysis()
         except Exception as e:
             self.exception(e)
+            return
+
         eqns = na.nodal_equations()
         self.ui.show_equations_dialog(eqns, 'Nodal equations')
 
@@ -469,12 +484,28 @@ class UIModelMPH(UIModelBase):
 
     def on_save(self):
 
-        filename = self.ui.save_file_dialog(self.filename)
+        filename = self.filename
         if filename == '':
             return
         self.save(filename)
         self.ui.save(filename)
 
+    def on_save_as(self):
+
+        filename = self.ui.save_file_dialog(self.filename)
+        if filename == '' or filename == ():
+            return
+        self.save(filename)
+        self.ui.save(filename)
+
+    def on_screenshot(self):
+
+        filename = self.ui.export_file_dialog(self.filename,
+                                              default_ext='.png')
+        if filename == '' or filename == ():
+            return
+        self.ui.screenshot(filename)
+
     def on_select(self, x, y):
 
         cpt = self.components.closest(x, y)
